c23456789012345678901234567890123456789012345678901234567890123456789012
c
c Forced convection of PTT fluid in fully-developed laminar annular flow for imposed
c constant wall temperatures at both walls (different temperatures),
c in the presence of viscous dissipation.
c
c Input data are: radius ratio, Brinkman number,Epsilon*We**2
c  and radial position (for the temperature)
c
c The calculations are carried out for all radius ratios from 0.01 to 0.99
c
c output data are integral quantities such as: inner wall Nusselt number
c outer wall Nussselt number and bulk (or mixing) temperature 
c
c  12th November 2005  Fernando Pinho and Paulo Coelho
c  CEFT- Centro de Estudos de Fenmenos de Transporte
c
       program PTTanulartemp
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1
c       COMMON k,br,UNui,UNuo,Tbulk,Twi
       DIMENSION A(15)
       DATA A/0.01,0.05,0.1,0.15,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.85,0.9,
     $ 0.95,0.99/

       OPEN (5,FILE='INPUTPTTTEMP.DAT')
       REWIND(5)
       READ(5,*) EPS,WE			!Epsilon,Weissenberg number
       READ(5,*) BRFIRST,BRLAST	!first and last Brinkman number
       CLOSE(5)

       OPEN (10,FILE='OUTPTTANT_BR.DAT')	!Output file for varying Brinkman number
       REWIND(10)
c       OPEN (11,FILE='OUTPTTANT_Q.DAT')	!Output file for varying heat flux ratio
c       REWIND(11)
       OPEN (15,FILE='OUTPTTTEMPT.DAT')	!Output of temperature profile
       REWIND(15)
       
       ewe=EPS*WE*WE			!Epsilon*We**2  
       
       
       DO III=1,15
       k=A(III)
       YY=k/(1.-k)			!Y 
       yin=1.				!y+inner
       yout=1./k			!y+outer
       npoints=100		!100 points across the annulus
       dely=(yout-yin)/npoints	

c       
c   Determination of ystarplus (ya) (the zero shear stress location) and X
c   This is an iterative calculation because ystarplus depends on X
c   and X depends on ystarplus
c
       XN= 1./((1.+k*k)/(1.-k)**2.-(1.+k)/(1.-k)*(1./DLOG(1./k)))     
       X=XN			!initial value of X
       XX=1.D-12		!initially a very small value
        write(*,*)'XN=',XN 
	
 1     CONTINUE
       IF (DABS(XX-X)/XX .GT. 1.D-8) THEN
       X=XX
       Wec=We*X
       a1=6.*DLOG(k)/(1.-k*k)/(1./k-1.)/(1./k-1.)
       a2=3.*k*k/(1.-k)/(1.-k)/(1.-k)/(1.-k)-2.*DLOG(k)/(32.D0*EPS*Wec*
     1    Wec*(1.-k)*(1.-k)*(1./k/k-1.))
       a3=-k*k/(1.-k)/(1.-k)/(1.-k)/(1.-k)*(1./(32.D0*EPS*Wec*Wec)+
     1    (1.+k*k)/2.D0/(1.-k)/(1.-k))
       aa=a2-a1*a1/3.
       b=a3-a1*a2/3.+2.*a1*a1*a1/27.
       d=b*b/4.+aa*aa*aa/27.
       pA=-b/2.+DSQRT(d)
       qA=-b/2.-DSQRT(d)
       yPOs=DSQRT(pA/DABS(pA)*(DABS(pA))**(1./3.)+qA/DABS(qA)*
     1         (DABS(qA))**(1./3.)-a1/3.)

       AI1=DLOG(1./k)/2./(k-1.)/(k-1.)+(k+1.)*(2*yPOs**2*(k-1.)-k-1.)/
     1     (8.*yPOs**2*(k-1.)*(k-1.))
       AI2=(yPOs*yPOs/2.+3./2./(k-1.)/(k-1.))*DLOG(1./k)+((1.+k)*
     1   (6.*yPOs**6.*(k-1.)**5.+18.*yPOs**4.*k*k*(k-1.)**3.-9.*yPOs*
     1    yPOs*k*k*(k-1.)*(k-1.)*(k+1.)+k*k*(k+1)*(2.*k*k+1.)))/
     1     (24.*yPOs*yPOs*yPOs*yPOs*k*k*(k-1.)**4.)
       ALFA=AI1*yPOs*yPOs*8.D0*(1.-k)/(1.+k)
       BETA1=-32.D0*ewe*yPOs*yPOs*yPOs*yPOs*AI2*8.D0*(1.-k)/(1.+k)
       DD=DSQRT(4.*ALFA*ALFA*ALFA+27.*BETA1)+3.**(3./2.)*DSQRT(BETA1)
       XX=432.**(1./6.)*(DD**(2./3.)-2.**(2./3.)*ALFA)/6./DSQRT(BETA1)
     1   /DD**(1./3.)
c       write(*,*)'XX=',XX,'yPOs=',yPOs
c       pause
       GOTO 1
       ELSE
        X=XX
        ya=yPOs*(1.-k)/k
       END IF
c   End of calculation of ystarplus and X

c   Calculation of various parameters and constants
       
       ALAMCA=2.*X*k*k*ya*ya*(96.*X*X*ewe*k*k*ya*ya-k*k+2.*k-1.)/
     1         (k-1.)/(k-1.)/(k-1.)/(k-1.)	!Capital Lambda
       PHI=32.*X*X*X*ewe*k*k*k*k*ya*ya*ya*ya/(k-1.)/(k-1.)/(k-1.)/(k-1.)
       c1=-2.*ALAMCA*DLOG(1.-k)+2.*PHI*k*k*ya*ya-ALAMCA/k/k/(ya*ya)+
     1    PHI/(k*k*k*k*ya*ya*ya*ya)
       OMEGA=32.*ewe*X*X*YY*YY*ya*ya
       write(*,*)'ALAMCA=',ALAMCA,'PHI=',PHI,'c1=',c1,'X=',X,'ya=',ya
       write(*,*)
       write(*,*)'**** W A I T ******'
c       pause

c  Now we run various Brinkman numbers
c

      WRITE(10,*) 'k=',k,'EpsilonWe**2=',ewe
      WRITE(10,*)'     br    ','         Nui     ','          Nuo    ',
     & '        Tbulk    '

c  We start with no viscous dissipation (Br=0)
       br=0.D0
        WRITE(10,'(4G17.8)') br,UNui(k,br),UNuo(k,br),Tbulk(k,br)
	     WRITE(15,*) 'Brinkman=',br,'k=',k,'EpsilonWe**2=',ewe
             WRITE(15,*) '     y  ','      Temperature   '
             DO LL=0,npoints	!Produce temperature profile
	      y=yin+LL*dely
	      WRITE(15,'(2G17.8)') y,Temp(k,br,y)
	     END DO
             WRITE(15,*)
             WRITE(15,*)
	     
c end of Brinkman zero	     

c Next, the negative followed by the positive Brinkman numbers

      DO ISIGN=1,2
         IF (ISIGN.EQ.1) THEN		!Brinkman negativo
          J1=DINT(DLOG10(BRLAST))
	  J2=DINT(DLOG10(BRFIRST))
	  JSTEP=-1
         ELSE				!Brinkman positivo
          J1=DINT(DLOG10(BRFIRST))
          J2=DINT(DLOG10(BRLAST))
	  JSTEP=1
         END IF
       DO J=J1,J2,JSTEP
         IF (ISIGN.EQ.1) THEN
          JJ1=8
	  JJ2=0
	  JJSTEP=-1
         ELSE
          JJ1=0
          JJ2=8
	  JJSTEP=1
         END IF
        
       DO JJ=JJ1,JJ2,JJSTEP
        aux=10.**(J)
        br=(-1)**ISIGN*aux*(1+JJ)
        br1=(-1)**ISIGN*aux*(1.35+JJ)
        br2=(-1)**ISIGN*aux*(1.7+JJ)
        IF (ISIGN .EQ. 1) THEN
         WRITE(10,'(4G17.8)') br2,UNui(k,br2),UNuo(k,br2),Tbulk(k,br2)
         WRITE(10,'(4G17.8)') br1,UNui(k,br1),UNuo(k,br1),Tbulk(k,br1)
         WRITE(10,'(4G17.8)') br,UNui(k,br),UNuo(k,br),Tbulk(k,br)	
	END IF
        IF (ISIGN .EQ. 2) THEN
         WRITE(10,'(4G17.8)') br,UNui(k,br),UNuo(k,br),Tbulk(k,br)
         WRITE(10,'(4G17.8)') br1,UNui(k,br1),UNuo(k,br1),Tbulk(k,br1)
         WRITE(10,'(4G17.8)') br2,UNui(k,br2),UNuo(k,br2),Tbulk(k,br2)
	END IF
	     WRITE(15,*) 'Brinkman=',br,'k=',k,'EpsilonWe**2=',ewe
             WRITE(15,*) '     y  ','      Temperature   '
             DO LL=0,npoints	!Produce temperature profile
	      y=yin+LL*dely
	      WRITE(15,'(2G17.8)') y,Temp(k,br,y)
	     END DO
             WRITE(15,*)
             WRITE(15,*)

       END DO
       END DO
        WRITE(10,*)
        WRITE(10,*)
       END DO
       
       END DO

c  end of all
      CLOSE(10)
      CLOSE(11)
      CLOSE(12)


      END


c  Definition of the various functions

       REAL*8 FUNCTION UNui(k,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1

c       COMMON k,br,UNui,UNuo,Tbulk,Twi
      
c determination of inner walll Nusselt number

      UNui=-2./YY*DTDYi(k,br)/(0.-Tbulk(k,br))
     
      RETURN
      END
     
     
       REAL*8 FUNCTION UNuo(k,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1
c       COMMON k,br,UNui,UNuo,Tbulk,Twi
c     
c determination of outer walll Nusselt number
c
c     
      UNuo=2./YY*DTDYo(k,br)/(1.-Tbulk(k,br))

     
      RETURN
      END
      
       REAL*8 FUNCTION Tbulk(k,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1
c       COMMON k,br,UNui,UNuo,Tbulk,Twi

       BETA=16.*br*ya*ya*X*X*YY*YY*YY*YY
     
c     
c determination of bulk temperature
c
c          
      c4=beta*ya**2*(4*OMEGA-1)*DLOG(k)/2+OMEGA*BETA*ya**4*(1
     $-k*k)/(4*DLOG(k))+beta*(1-k**4)*(4*OMEGA-1)/(16*k**4*ya**2*DLOG(k
     $))+OMEGA*beta*(k**6-1)/(36*k**6*ya**4*DLOG(k))+(3*OMEGA*beta*(k*k
     $-1)+BETA*(1-k*k)-2*k*k)/(2*k*k*DLOG(k))

      C5=OMEGA*BETA*ya**4/4+BETA*(1-4*OMEGA)/(16*ya*ya)+OMEGA
     $*BETA/(36*ya**4)+BETA*(3*OMEGA-1)/2

      
      Tbulk=ALAMCA*beta*ya**2*(4*OMEGA-1)*DLOG(k)**2*DLOG(1-k)/(1-k**
     $2)+2*ALAMCA*c4*DLOG(k)*DLOG(1-k)/(k**2-1)+ALAMCA*OMEGA*beta*k**2*y
     $a**4*DLOG(k)*DLOG(1-k)/(1-k**2)+ALAMCA*beta*ya**2*(4*OMEGA-1)*DLOG
     $(k)*DLOG(1-k)/(1-k**2)-ALAMCA*c4*DLOG(1-k)+2*ALAMCA*c5*DLOG(1-k)+A
     $LAMCA*beta*ya**2*(4*OMEGA-1)*DLOG(1-k)/2+ALAMCA*beta*(k**4+k**2+1)
     $*(4*OMEGA-1)*DLOG(1-k)/(24*k**4*ya**2)-ALAMCA*OMEGA*beta*(k**6+k**
     $4+k**2+1)*DLOG(1-k)/(72*k**6*ya**4)+ALAMCA*beta*(k**2+1)*(1-3*OMEG
     $A)*DLOG(1-k)/(2*k**2)+2*PHI*beta*k**2*ya**4*(4*OMEGA-1)*DLOG(k)*
     $*3/(3*(1-k**2))+2*PHI*c4*k**2*ya**2*DLOG(k)**2/(k**2-1)+ALAMCA*O
     $MEGA*beta*k**2*ya**4*DLOG(k)**2/(2*(k**2-1))+beta*ya**2*(ALAMCA+c1
     $)*(4*OMEGA-1)*DLOG(k)**2/(2*(1-k**2))+PHI*beta*(4*OMEGA-1)*DLOG(
     $k)**2/(6*k**4*ya**2*(k**2-1))+ALAMCA*beta*(4*OMEGA-1)*DLOG(k)**2/(
     $4*k**2*(1-k**2))+ALAMCA*c4*DLOG(k)/(2*k**2*ya**2*(k**2-1))+PHI*c
     $4*DLOG(k)/(3*k**4*ya**4*(1-k**2))+c4*(ALAMCA*(k**2+1)+c1)*DLOG(k)/
     $(k**2-1)+4*PHI*c5*k**2*ya**2*DLOG(k)/(1-k**2)+2*ALAMCA*c5*k**2*D
     $LOG(k)/(1-k**2)+OMEGA*beta*c1*k**2*ya**4*DLOG(k)/(2*(1-k**2))+beta
     $*ya**2*(4*OMEGA-1)*(ALAMCA*(k**2+2)+c1)*DLOG(k)/(2*(1-k**2))+beta*
     $(4*OMEGA-1)*(4*PHI-3*ALAMCA*k**6)*DLOG(k)/(72*k**4*ya**2*(k**2-1
     $))+ALAMCA*OMEGA*beta*k**2*DLOG(k)/(72*ya**4*(k**2-1))+ALAMCA*beta*
     $(4*OMEGA*(3*k**4-1)-4*k**4+1)*DLOG(k)/(8*k**2*(k**2-1))-ALAMCA*c4*
     $(k**2+1)/(8*k**2*ya**2)+PHI*c4*(k**4+k**2+1)/(18*k**4*ya**4)-c4*
     $(2*ALAMCA+c1)/2+ALAMCA*c5*(k**2+1)/(2*k**2*ya**2)-PHI*c5*(k**4+k
     $**2+1)/(3*k**4*ya**4)+c5*(ALAMCA+c1)+PHI*OMEGA*beta*k**2*ya**6/2
     $+beta*ya**2*(4*PHI*(3*OMEGA-1)+ALAMCA*(11*OMEGA-3)+c1*(4*OMEGA-1
     $))/4-beta*(k**4+k**2+1)*(4*PHI*(2*OMEGA-1)+3*(ALAMCA*(68*OMEGA-2
     $3)-3*c1*(4*OMEGA-1)))/(432*k**4*ya**2)+beta*(k**6+k**4+k**2+1)*(72
     $*PHI*(3*OMEGA-1)+ALAMCA*(35*OMEGA-9)-4*OMEGA*c1)/(576*k**6*ya**4
     $)-beta*(k**8+k**6+k**4+k**2+1)*(9*PHI*(4*OMEGA-1)+4*ALAMCA*OMEGA
     $)/(720*k**8*ya**6)+PHI*OMEGA*beta*(k**10+k**8+
     $k**6+k**4+k**2+1)/(216*k**10*ya**8)-beta*(k**2+1)*(2*PHI*
     $(2*OMEGA-1)+ALAMCA*(8*OMEGA-3)+8*c1*(3*OMEGA-1))/(32*k**2)



      RETURN
      END


       REAL*8 FUNCTION Temp(k,br,y)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1

       BETA=16.*br*ya*ya*X*X*YY*YY*YY*YY

c determination of temperature profile
      c4=beta*ya**2*(4*OMEGA-1)*DLOG(k)/2+OMEGA*BETA*ya**4*(1
     $-k*k)/(4*DLOG(k))+beta*(1-k**4)*(4*OMEGA-1)/(16*k**4*ya**2*DLOG(k
     $))+OMEGA*beta*(k**6-1)/(36*k**6*ya**4*DLOG(k))+(3*OMEGA*beta*(k*k
     $-1)+BETA*(1-k*k)-2*k*k)/(2*k*k*DLOG(k))

      C5=OMEGA*BETA*ya**4/4+BETA*(1-4*OMEGA)/(16*ya*ya)+OMEGA
     $*BETA/(36*ya**4)+BETA*(3*OMEGA-1)/2

      Temp=beta*ya**2*(4*OMEGA-1)*DLOG(y)**2/2+c4*DLOG(y)-OMEGA*
     $beta*ya**4/(4*y**2)+beta*y**4*(4*OMEGA-1)/(16*ya**2)-
     $OMEGA*beta*y**6/(36*ya**4)-(beta*y**2*(3*OMEGA-1)-2*c5)/2

      
      RETURN
      END


       REAL*8 FUNCTION DTDYi(k,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1

       beta=16.*br*ya*ya*X*X*YY*YY*YY*YY

c determination of temperature profile
      c4=beta*ya**2*(4*OMEGA-1)*DLOG(k)/2+OMEGA*BETA*ya**4*(1
     $-k*k)/(4*DLOG(k))+beta*(1-k**4)*(4*OMEGA-1)/(16*k**4*ya**2*DLOG(k
     $))+OMEGA*beta*(k**6-1)/(36*k**6*ya**4*DLOG(k))+(3*OMEGA*beta*(k*k
     $-1)+BETA*(1-k*k)-2*k*k)/(2*k*k*DLOG(k))

      DTDYi=c4+OMEGA*beta*ya**4/2+beta*(4*OMEGA-1)/(4*ya**2)-OMEGA*
     $beta/(6*ya**4)-beta*(3*OMEGA-1)

      
      RETURN
      END

       REAL*8 FUNCTION DTDYo(k,br)
       IMPLICIT REAL*8(A-H,O-Z,k)
       COMMON ALAMCA,PHI,OMEGA,BETA,X,YY,ya,c1

       beta=16.*br*ya*ya*X*X*YY*YY*YY*YY

c determination of temperature profile
      c4=beta*ya**2*(4*OMEGA-1)*DLOG(k)/2+OMEGA*BETA*ya**4*(1
     $-k*k)/(4*DLOG(k))+beta*(1-k**4)*(4*OMEGA-1)/(16*k**4*ya**2*DLOG(k
     $))+OMEGA*beta*(k**6-1)/(36*k**6*ya**4*DLOG(k))+(3*OMEGA*beta*(k*k
     $-1)+BETA*(1-k*k)-2*k*k)/(2*k*k*DLOG(k))

      DTDYo=beta*k*ya*ya*(1-4*OMEGA)*DLOG(k)+c4*k+OMEGA*beta*k**3*
     $ya**4/2+beta*(4*OMEGA-1)/(4*k**3*ya*ya)-OMEGA*beta/(6*k**5*ya**4
     $)-beta*(3*OMEGA-1)/k

      
      RETURN
      END



